"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DecodeContext = void 0;
const data_1 = require("../data");
const texts_1 = require("../errors/texts");
var DecodeStage;
(function (DecodeStage) {
    DecodeStage[DecodeStage["Create"] = 0] = "Create";
    DecodeStage[DecodeStage["Init"] = 1] = "Init";
})(DecodeStage || (DecodeStage = {}));
class DecodeContext {
    constructor(_target) {
        this._target = _target;
        this._stage = DecodeStage.Create;
    }
    next() {
        this._stage = DecodeStage.Init;
    }
    decode(value) {
        if (this._stage === DecodeStage.Create) {
            throw (0, texts_1.getErrorByCode)("decode/create/decode/call")();
        }
        if (value !== null && typeof value === "object") {
            throw (0, texts_1.getErrorByCode)("decode/init/decode/bad-type")(value);
        }
        const decodedPrimitive = (0, data_1.tryDecodeScalar)(value);
        switch (decodedPrimitive) {
            case data_1.noResultPlaceholder:
                return this._target[value];
            case data_1.unknownScalar:
                throw (0, texts_1.getErrorByCode)("decode/init/decode/unknown-scalar")(value);
            case data_1.badType:
                throw (0, texts_1.getErrorByCode)("decode/init/decode/bad-type")(value);
            default:
                return decodedPrimitive;
        }
    }
}
exports.DecodeContext = DecodeContext;
//# sourceMappingURL=decode-context.js.map