"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typedArrayEncodings = exports.createBinEncoding = exports.sharedArrayBufferEncoding = exports.arrayBufferEncoding = void 0;
const interface_1 = require("../interface");
const utils_1 = require("../utils");
const base64_js_1 = require("base64-js");
const opt_types_1 = require("../opt-types");
const fixed_indexes_1 = require("./fixed-indexes");
const utils_2 = require("./utils");
exports.arrayBufferEncoding = (0, utils_2.defineProtoEncoding)(class ArrayBufferEncoding extends interface_1.PrototypeEncoding {
    constructor() {
        super(...arguments);
        this.name = (0, utils_1.getBuiltInEncodingName)("ArrayBuffer");
        this.version = 0;
        this.fixedIndex = fixed_indexes_1.FixedIndexes.ArrayBuffer;
        this.encodes = ArrayBuffer.prototype;
        this.decoder = {
            create(encodedValue, ctx) {
                const byteArray = (0, base64_js_1.toByteArray)(encodedValue);
                return byteArray.buffer;
            }
        };
    }
    encode(input, ctx) {
        const b64 = (0, base64_js_1.fromByteArray)(new Uint8Array(input));
        return b64;
    }
});
exports.sharedArrayBufferEncoding = (0, utils_2.defineProtoEncoding)(class SharedArrayBufferEncoding extends interface_1.PrototypeEncoding {
    constructor() {
        super(...arguments);
        this.fixedIndex = fixed_indexes_1.FixedIndexes.SharedArrayBuffer;
        this.name = (0, utils_1.getBuiltInEncodingName)("SharedArrayBuffer");
        this.version = 0;
        this.encodes = opt_types_1._SharedArrayBuffer.prototype;
        this.encode = exports.arrayBufferEncoding.encode.bind(exports.arrayBufferEncoding);
        this.decoder = {
            create(encodedValue, ctx) {
                // This is not performant, but it's an uncommon use-case.
                const byteArray = (0, base64_js_1.toByteArray)(encodedValue);
                const sharedBuffer = new opt_types_1._SharedArrayBuffer(byteArray.byteLength);
                const sharedByteArray = new Uint8Array(sharedBuffer);
                sharedByteArray.set(byteArray, 0);
                return sharedBuffer;
            }
        };
    }
});
function createBinEncoding(index, ctor) {
    if (!ctor)
        return undefined;
    return (0, utils_2.defineProtoEncoding)(class BinaryTypeEncoding extends interface_1.PrototypeEncoding {
        constructor() {
            super(...arguments);
            this.fixedIndex = index;
            this.name = (0, utils_1.getBuiltInEncodingName)(ctor.name);
            this.version = 0;
            this.encodes = ctor.prototype;
            this.decoder = {
                create(encodedValue, ctx) {
                    const buffer = exports.arrayBufferEncoding.decoder.create(encodedValue, ctx);
                    return new ctor(buffer);
                }
            };
        }
        encode(input, ctx) {
            return exports.arrayBufferEncoding.encode(input.buffer, ctx);
        }
    });
}
exports.createBinEncoding = createBinEncoding;
exports.typedArrayEncodings = [
    createBinEncoding(fixed_indexes_1.FixedIndexes.Uint8Array, Uint8Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Uint8ClampedArray, Uint8ClampedArray),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Uint16Array, Uint16Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Uint32Array, Uint32Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Int8Array, Int8Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Int16Array, Int16Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Int32Array, Int32Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Float32Array, Float32Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.Float64Array, Float64Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.DataView, DataView),
    createBinEncoding(fixed_indexes_1.FixedIndexes.BigInt64Array, opt_types_1._BigInt64Array),
    createBinEncoding(fixed_indexes_1.FixedIndexes.BigUint64Array, opt_types_1._BigUint64Array)
]
    .filter(x => !!x)
    .map(x => x);
//# sourceMappingURL=binary.js.map