"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapperEncodings = exports.makeObjectWrappedEncoding = exports.dateEncoding = exports.regexpEncoding = void 0;
const interface_1 = require("../interface");
const utils_1 = require("../utils");
const fixed_indexes_1 = require("./fixed-indexes");
const utils_2 = require("./utils");
exports.regexpEncoding = (0, utils_2.defineProtoEncoding)(class RegexpEncoding extends interface_1.PrototypeEncoding {
    constructor() {
        super(...arguments);
        this.encodes = RegExp.prototype;
        this.version = 0;
        this.name = (0, utils_1.getBuiltInEncodingName)("RegExp");
        this.fixedIndex = fixed_indexes_1.FixedIndexes.RegExp;
        this.decoder = {
            create(input, ctx) {
                if (typeof input === "string") {
                    return new RegExp(input);
                }
                else {
                    // A bit wasteful, but these shouldn't be common and this avoids having to do parsing.
                    return new RegExp(input[0], input[1]);
                }
            }
        };
    }
    encode({ source, flags }, ctx) {
        return flags ? [source, flags] : source;
    }
});
exports.dateEncoding = (0, utils_2.defineProtoEncoding)(class DateEncoding extends interface_1.PrototypeEncoding {
    constructor() {
        super(...arguments);
        this.encodes = Date.prototype;
        this.version = 0;
        this.fixedIndex = fixed_indexes_1.FixedIndexes.Date;
        this.name = (0, utils_1.getBuiltInEncodingName)("Date");
        this.decoder = {
            create(encodedValue, ctx) {
                return new Date(encodedValue);
            }
        };
    }
    encode(input, ctx) {
        return input.getTime();
    }
});
function makeObjectWrappedEncoding(index, ctor) {
    return (0, utils_2.defineProtoEncoding)(class ObjectWrapperEncoding extends interface_1.PrototypeEncoding {
        constructor() {
            super(...arguments);
            this.name = (0, utils_1.getBuiltInEncodingName)(ctor.name);
            this.version = 0;
            this.fixedIndex = index;
            this.encodes = ctor.prototype;
            this.decoder = {
                create(encodedValue, ctx) {
                    return new ctor(encodedValue);
                }
            };
        }
        encode(input, ctx) {
            return input.valueOf();
        }
    });
}
exports.makeObjectWrappedEncoding = makeObjectWrappedEncoding;
exports.wrapperEncodings = [
    makeObjectWrappedEncoding(fixed_indexes_1.FixedIndexes.FundNumber, Number),
    makeObjectWrappedEncoding(fixed_indexes_1.FixedIndexes.FundBool, Boolean),
    makeObjectWrappedEncoding(fixed_indexes_1.FixedIndexes.FundString, String)
];
//# sourceMappingURL=scalar.js.map