"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mustParseEncodingKey = exports.defineProtoEncoding = exports.isSymbolSpecifier = void 0;
const utils_1 = require("../utils");
const texts_1 = require("../errors/texts");
function isSymbolSpecifier(encoding) {
    return typeof encoding.encodes === "symbol";
}
exports.isSymbolSpecifier = isSymbolSpecifier;
function defineProtoEncoding(cls) {
    return new cls();
}
exports.defineProtoEncoding = defineProtoEncoding;
function mustParseEncodingKey(key) {
    const lastDot = key.lastIndexOf(".");
    if (lastDot === -1) {
        throw (0, texts_1.getErrorByCode)("decode/keys/bad-format")(key);
    }
    const strPostfix = key.slice(lastDot + 1);
    const name = key.slice(0, lastDot);
    if (strPostfix === "S") {
        return {
            type: "symbol",
            name
        };
    }
    if (!strPostfix.startsWith("v")) {
        throw (0, texts_1.getErrorByCode)("decode/keys/bad-format")(key);
    }
    const strVersion = strPostfix.slice(1);
    if (!(0, utils_1.isNumericString)(strVersion)) {
        throw (0, texts_1.getErrorByCode)("decode/keys/bad-format")(key);
    }
    if (!name) {
        throw (0, texts_1.getErrorByCode)("decode/keys/bad-format")(key);
    }
    return {
        type: "prototype",
        name,
        version: +strVersion
    };
}
exports.mustParseEncodingKey = mustParseEncodingKey;
//# sourceMappingURL=utils.js.map