import { Encoding, PrototypeEncoding, SymbolEncoding } from "../interface";
import { PreszrError } from "./index";
export declare const errorDefinitions: {
    "bug/config/fixed-index-collision"(nw: Encoding, existing: Encoding): string;
    "bug/config/unknown-encoding"(encoding: any): string;
    "bug/encode/proto-without-match"(proto: object): string;
    "bug/encode/no-highest-version"(encoding: PrototypeEncoding): string;
    "config/bad-type"(value: any): string;
    "config/encodes/not-array"(value: any): string;
    "config/proto/couldnt-get-prototype"(ctor: Function): string;
    "config/proto/encoding-exists"(encoding: PrototypeEncoding): string;
    "config/proto/name-collision"(existing: PrototypeEncoding, encoding: PrototypeEncoding): string;
    "config/proto/proto-collision"(existing: PrototypeEncoding, nw: PrototypeEncoding): string;
    "config/proto/version/bad-type"(encoding: PrototypeEncoding): string;
    "config/proto/version/bad-range"([min, max]: number[], encoding: PrototypeEncoding): string;
    "config/proto/version/not-safe"(encoding: PrototypeEncoding): string;
    "config/spec/bad-encodes"(type: string): string;
    "config/spec/name-illegal-builtin"(proto: object): string;
    "config/spec/proto/no-name"(proto: object): string;
    "config/spec/proto/bad-name"(name: string): string;
    "config/spec/bad-type"(spec: any): string;
    "config/spec/no-encodes"(): string;
    "config/symbol/already-encoded"(existing: SymbolEncoding, nw: SymbolEncoding): string;
    "config/symbol/no-name"(s: symbol): string;
    "config/symbol/name-exists"(existing: SymbolEncoding): string;
    "decode/create/decode/call"(): string;
    "decode/init/decode/unknown-scalar"(input: any): string;
    "decode/init/decode/bad-reference"(input: any): string;
    "decode/init/decode/bad-type"(input: any): string;
    "decode/init/decode/not-numeric"(input: any): string;
    "decode/input/bad-header"(header: object): string;
    "decode/input/header/empty-array"(): string;
    "decode/input/version/mismatch"(inputVersion: string, myVersion: string): string;
    "decode/input/version/not-numeric"(version: string): string;
    "decode/input/version/not-string"(value: string): string;
    "decode/input/header/no-map"(): string;
    "decode/input/header/no-metadata"(): string;
    "decode/input/header/no-keys"(): string;
    "decode/input/header/too-long"(header: any[]): string;
    "decode/input/no-data"(): string;
    "decode/input/empty-array"(): string;
    "decode/input/not-array"(input: any): string;
    "decode/input/unknown-scalar"(v: any): string;
    "decode/input/bad-type"(v: any): string;
    "decode/keys/bad-type"(value: any): string;
    "decode/keys/bad-format"(key: string): string;
    "decode/map/unknown-builtin-index"(index: number): string;
    "decode/map/unknown-index"(index: number): string;
    "decode/keys/unknown-proto"(name: string): string;
    "decode/keys/unknown-proto-version"(name: string, wantedVersion: number, existing: PrototypeEncoding): string;
    "decode/keys/unknown-symbol"(name: string): string;
};
export declare type ErrorDefinitions = typeof errorDefinitions;
export declare type ErrorCode = keyof ErrorDefinitions;
export declare function getErrorByCode<T extends ErrorCode>(code: T): (...args: Parameters<{
    "bug/config/fixed-index-collision"(nw: Encoding, existing: Encoding): string;
    "bug/config/unknown-encoding"(encoding: any): string;
    "bug/encode/proto-without-match"(proto: object): string;
    "bug/encode/no-highest-version"(encoding: PrototypeEncoding<object>): string;
    "config/bad-type"(value: any): string;
    "config/encodes/not-array"(value: any): string;
    "config/proto/couldnt-get-prototype"(ctor: Function): string;
    "config/proto/encoding-exists"(encoding: PrototypeEncoding<object>): string;
    "config/proto/name-collision"(existing: PrototypeEncoding<object>, encoding: PrototypeEncoding<object>): string;
    "config/proto/proto-collision"(existing: PrototypeEncoding<object>, nw: PrototypeEncoding<object>): string;
    "config/proto/version/bad-type"(encoding: PrototypeEncoding<object>): string;
    "config/proto/version/bad-range"([min, max]: number[], encoding: PrototypeEncoding<object>): string;
    "config/proto/version/not-safe"(encoding: PrototypeEncoding<object>): string;
    "config/spec/bad-encodes"(type: string): string;
    "config/spec/name-illegal-builtin"(proto: object): string;
    "config/spec/proto/no-name"(proto: object): string;
    "config/spec/proto/bad-name"(name: string): string;
    "config/spec/bad-type"(spec: any): string;
    "config/spec/no-encodes"(): string;
    "config/symbol/already-encoded"(existing: SymbolEncoding, nw: SymbolEncoding): string;
    "config/symbol/no-name"(s: symbol): string;
    "config/symbol/name-exists"(existing: SymbolEncoding): string;
    "decode/create/decode/call"(): string;
    "decode/init/decode/unknown-scalar"(input: any): string;
    "decode/init/decode/bad-reference"(input: any): string;
    "decode/init/decode/bad-type"(input: any): string;
    "decode/init/decode/not-numeric"(input: any): string;
    "decode/input/bad-header"(header: object): string;
    "decode/input/header/empty-array"(): string;
    "decode/input/version/mismatch"(inputVersion: string, myVersion: string): string;
    "decode/input/version/not-numeric"(version: string): string;
    "decode/input/version/not-string"(value: string): string;
    "decode/input/header/no-map"(): string;
    "decode/input/header/no-metadata"(): string;
    "decode/input/header/no-keys"(): string;
    "decode/input/header/too-long"(header: any[]): string;
    "decode/input/no-data"(): string;
    "decode/input/empty-array"(): string;
    "decode/input/not-array"(input: any): string;
    "decode/input/unknown-scalar"(v: any): string;
    "decode/input/bad-type"(v: any): string;
    "decode/keys/bad-type"(value: any): string;
    "decode/keys/bad-format"(key: string): string;
    "decode/map/unknown-builtin-index"(index: number): string;
    "decode/map/unknown-index"(index: number): string;
    "decode/keys/unknown-proto"(name: string): string;
    "decode/keys/unknown-proto-version"(name: string, wantedVersion: number, existing: PrototypeEncoding<object>): string;
    "decode/keys/unknown-symbol"(name: string): string;
}[T]>) => PreszrError;
//# sourceMappingURL=texts.d.ts.map