"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrototypeEncoding = exports.PreszrUnsupportedValue = exports.SymbolEncoding = exports.BaseEncoding = void 0;
const utils_1 = require("./utils");
const texts_1 = require("./errors/texts");
class BaseEncoding {
    get [Symbol.toStringTag]() {
        return this._toString();
    }
    toString() {
        return this[Symbol.toStringTag];
    }
}
exports.BaseEncoding = BaseEncoding;
class SymbolEncoding extends BaseEncoding {
    constructor(name, encodes, fixedIndex, metadata) {
        super();
        this.name = name;
        this.encodes = encodes;
        this.fixedIndex = fixedIndex;
        this.metadata = metadata;
    }
    _toString() {
        return `[PreszrSymbolEncoding "${this.name}" ${(0, utils_1.getSymbolName)(this.encodes)}]`;
    }
    get key() {
        return `${this.name}.S`;
    }
    static fromSymbol(s) {
        const name = (0, utils_1.getSymbolName)(s);
        if (!name) {
            throw (0, texts_1.getErrorByCode)("config/symbol/no-name")(s);
        }
        return new SymbolEncoding(name, s);
    }
    static fromSpecifier(spec) {
        var _a;
        if (!spec.encodes) {
            throw (0, texts_1.getErrorByCode)("config/spec/no-encodes")();
        }
        const name = (_a = spec.name) !== null && _a !== void 0 ? _a : (0, utils_1.getSymbolName)(spec.encodes);
        if (!name) {
            throw (0, texts_1.getErrorByCode)("config/symbol/no-name")(spec.encodes);
        }
        return new SymbolEncoding(name, spec.encodes);
    }
}
exports.SymbolEncoding = SymbolEncoding;
class PreszrUnsupportedValue {
    constructor(type) {
        this.type = type;
    }
}
exports.PreszrUnsupportedValue = PreszrUnsupportedValue;
class PrototypeEncoding extends BaseEncoding {
    get key() {
        return `${this.name}.v${this.version}`;
    }
    _toString() {
        return `[PreszrPrototypeEncoding "${this.name}@${this.version}" ${(0, utils_1.getPrototypeName)(this.encodes)}]`;
    }
    mustBeCompatible(other) {
        if (this.encodes !== other.encodes) {
            throw (0, texts_1.getErrorByCode)("config/proto/proto-collision")(other, this);
        }
        if (this.name !== other.name) {
            throw (0, texts_1.getErrorByCode)("config/proto/name-collision")(other, this);
        }
        if (this.fixedIndex !== other.fixedIndex) {
            throw (0, texts_1.getErrorByCode)("bug/config/fixed-index-collision")(this, other);
        }
    }
}
exports.PrototypeEncoding = PrototypeEncoding;
//# sourceMappingURL=interface.js.map